package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallMemberAddress;
import com.ruoyi.mall.service.IMallMemberAddressService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 收货地址Controller
 * 
 * @author chang
 * @date 2021-11-25
 */
@RestController
@RequestMapping("/mall/mallMemberAddress")
public class MallMemberAddressController extends BaseController
{
    @Autowired
    private IMallMemberAddressService mallMemberAddressService;

    /**
     * 查询收货地址列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberAddress:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallMemberAddress mallMemberAddress)
    {
        startPage();
        List<MallMemberAddress> list = mallMemberAddressService.selectMallMemberAddressList(mallMemberAddress);
        return getDataTable(list);
    }

    /**
     * 导出收货地址列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberAddress:export')")
    @Log(title = "收货地址", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallMemberAddress mallMemberAddress)
    {
        List<MallMemberAddress> list = mallMemberAddressService.selectMallMemberAddressList(mallMemberAddress);
        ExcelUtil<MallMemberAddress> util = new ExcelUtil<MallMemberAddress>(MallMemberAddress.class);
        return util.exportExcel(list, "收货地址数据");
    }

    /**
     * 获取收货地址详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberAddress:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallMemberAddressService.selectMallMemberAddressById(id));
    }

    /**
     * 新增收货地址
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberAddress:add')")
    @Log(title = "收货地址", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallMemberAddress mallMemberAddress)
    {
        return toAjax(mallMemberAddressService.insertMallMemberAddress(mallMemberAddress));
    }

    /**
     * 修改收货地址
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberAddress:edit')")
    @Log(title = "收货地址", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallMemberAddress mallMemberAddress)
    {
        return toAjax(mallMemberAddressService.updateMallMemberAddress(mallMemberAddress));
    }

    /**
     * 删除收货地址
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberAddress:remove')")
    @Log(title = "收货地址", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallMemberAddressService.deleteMallMemberAddressByIds(ids));
    }
}
